@@ -1,3 +1,4 @@
+import logging
 from pathlib import Path
 
 import typer
@@ -5,6 +6,8 @@ import typer
 from parse_qwantz.main import main
 from parse_qwantz.prepare_image import ImageError
 
+logger = logging.getLogger()
+
 app = typer.Typer()
 
 
@@ -12,10 +15,12 @@ app = typer.Typer()
 def cli(
     input_paths: list[Path] = typer.Argument(..., help="Paths to one or more image and/or directory", exists=True),
     output_dir: Path = typer.Option(None, help="Path to the output directory", exists=True, file_okay=False),
+    log_level: str = typer.Option('WARNING', help="Log level"),
     debug: bool = typer.Option(False, help="Enable debug features."),
     show_boxes: bool = typer.Option(False, help="Show character boxes (for debug)")
 ):
     """Generate transcripts for Ryan North's Dinosaur Comics from https://qwantz.com"""
+    logger.setLevel(getattr(logging, log_level.upper()))
     for input_path in input_paths:
         if input_path.is_dir():
             image_paths = (child_path for child_path in input_path.iterdir() if child_path.is_file())
