@@ -1,3 +1,4 @@
+import logging
 from functools import cached_property
 
 from dataclasses import dataclass
@@ -7,6 +8,8 @@ from parse_qwantz.fonts import Font, CharBox
 from parse_qwantz.pixels import Pixel
 from parse_qwantz.simple_image import SimpleImage
 
+logger = logging.getLogger()
+
 
 @dataclass
 class TextLine:
@@ -54,8 +57,8 @@ class TextLine:
 
 def try_text_line(start: Pixel, image: SimpleImage, font: Font) -> TextLine | None:
     x0, y0 = start
-    max_x_offset = font.width - 4
-    max_y_offset = font.height - 3
+    max_x_offset = font.width - 3
+    max_y_offset = font.height - 1
     for x in range(x0, x0 - max_x_offset - 1, -1):
         for y in range(y0, y0 - max_y_offset - 1, -1):
             line = get_text_line(Pixel(x, y), image, font)
@@ -75,18 +78,25 @@ def get_text_line(start: Pixel, image: SimpleImage, font: Font) -> TextLine | No
         x += char_box.box.width
         if x > image.width - font.width:
             break
-        char_box = font.get_char(Pixel(x, y), image, expect_bold=is_bold)
+        allow_short_space = not spaces and char_boxes[-1].char == '.'
+        char_box = font.get_char(Pixel(x, y), image, expect_bold=is_bold, allow_short_space=allow_short_space)
         if char_box is None:
             if spaces:
                 offsets = ((-2, 0), (-1, 0), (1, 0), (0, -1), (0, 1))
             else:
-                offsets = ((-2, 0), (-1, 0), (1, 0))
+                offsets = ((-1, 0), (1, 0))
             for offset in offsets:
                 off_x, off_y = offset
                 char_box = font.get_char(Pixel(x + off_x, y + off_y), image, expect_space=False)
                 if char_box and char_box.char == ' ':
                     char_box = None
                 if char_box is not None:
+                    content_so_far = ''.join(char_box.char for char_box in char_boxes)
+                    if off_x == -2 or off_y != 0:
+                        logger.warning(
+                            f"Inline offset after {content_so_far + ' '*len(spaces)!r},"
+                            f" before {char_box.char!r}: {(off_x, off_y)}"
+                        )
                     x += off_x
                     y += off_y
                     break
@@ -111,7 +121,7 @@ def get_text_line(start: Pixel, image: SimpleImage, font: Font) -> TextLine | No
                 spaces = []
             char_boxes.append(char_box)
             is_bold = char_box.is_bold
-    if len(char_boxes) <= 2 and all(char_box.char in "\",.'`|-/\\" for char_box in char_boxes):
+    if len(char_boxes) <= 2 and all(char_box.char in "\",.'‘’“”|-/" for char_box in char_boxes):
         return
     if len(char_boxes) >= 5 and all(char_box.char == ' ' for char_box in char_boxes[1::2]):
         char_boxes = char_boxes[0::2]
